@@ -60,7 +60,7 @@ write_pdf_clicked (GtkWidget *button, GooCanvas *canvas)
 static void
 zoom_changed (GtkAdjustment *adj, GooCanvas *canvas)
 {
-  goo_canvas_set_scale (canvas, adj->value);
+  goo_canvas_set_scale (canvas, gtk_adjustment_get_value (adj));
 }
 
 
@@ -75,11 +75,11 @@ center_toggled (GtkToggleButton *button, gpointer data)
 static void
 anchor_toggled (GtkWidget *button, GooCanvas *canvas)
 {
-  GtkAnchorType anchor;
+  GooCanvasAnchorType anchor;
 
   anchor = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "anchor"));
 
-  if (GTK_TOGGLE_BUTTON (button)->active)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
     g_object_set (canvas, "anchor", anchor, NULL);
 }
 
@@ -306,7 +306,7 @@ on_button_press (GooCanvasItem *item,
 				   GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE_MASK,
 				   fleur,
 				   event->time);
-	  gdk_cursor_unref (fleur);
+	  g_object_unref (fleur);
 	  dragging = TRUE;
 	}
       break;
@@ -395,7 +395,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 	GtkAdjustment *adj;
 	GSList *group = NULL;
 
-	vbox = gtk_vbox_new (FALSE, 4);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
 	gtk_widget_show (vbox);
 
@@ -403,7 +403,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 
-	hbox = gtk_hbox_new (FALSE, 4);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
 
@@ -431,7 +431,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 
-	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 50.00, 0.05, 0.50, 0.0));
+	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 50.00, 0.05, 0.50, 0.50));
 	w = gtk_spin_button_new (adj, 0.0, 2);
 	g_signal_connect (adj, "value_changed",
 			  G_CALLBACK (zoom_changed),
@@ -495,7 +495,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (change_bounds_clicked),
 			  canvas);
 
-	hbox = gtk_hbox_new (FALSE, 4);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
 
@@ -540,7 +540,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_NW));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_NW));
 
 	w = gtk_radio_button_new_with_label (group, "N");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -550,7 +550,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_N));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_N));
 
 	w = gtk_radio_button_new_with_label (group, "NE");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -560,7 +560,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_NE));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_NE));
 
 	w = gtk_radio_button_new_with_label (group, "W");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -570,7 +570,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_W));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_W));
 
 	w = gtk_radio_button_new_with_label (group, "C");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -580,7 +580,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_CENTER));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_CENTER));
 
 	w = gtk_radio_button_new_with_label (group, "E");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -590,7 +590,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_E));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_E));
 
 	w = gtk_radio_button_new_with_label (group, "SW");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -600,7 +600,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_SW));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_SW));
 
 	w = gtk_radio_button_new_with_label (group, "S");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -610,7 +610,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_S));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_S));
 
 	w = gtk_radio_button_new_with_label (group, "SE");
 	group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (w));
@@ -620,7 +620,7 @@ create_canvas_primitives (GooCanvasItemModel *model,
 			  G_CALLBACK (anchor_toggled),
 			  canvas);
 	g_object_set_data (G_OBJECT (w), "anchor",
-			   GINT_TO_POINTER (GTK_ANCHOR_SE));
+			   GINT_TO_POINTER (GOO_CANVAS_ANCHOR_SE));
 
 	
 	/* Layout the stuff */
@@ -658,7 +658,7 @@ setup_heading (GooCanvasItemModel *root, char *text, int pos)
   double y = (pos / 3) * 150 + 5;
   GooCanvasItemModel *item;
 
-  item = goo_canvas_text_model_new (root, text, x, y, -1, GTK_ANCHOR_N,
+  item = goo_canvas_text_model_new (root, text, x, y, -1, GOO_CANVAS_ANCHOR_N,
 				    "font", "Sans 12",
 				    NULL);
   goo_canvas_item_model_skew_y (item, 30, x, y);
@@ -738,7 +738,7 @@ create_stipple (const char *color_name, guchar stipple_data[16])
 static void
 setup_rectangles (GooCanvasItemModel *root)
 {
-  GooCanvasItemModel *item;
+  GooCanvasItemModel *item G_GNUC_UNUSED;
   cairo_pattern_t *pattern;
   static guchar stipple_data[16] = {
     0, 0, 0, 255,   0, 0, 0, 0,   0, 0, 0, 0,     0, 0, 0, 255
@@ -785,7 +785,7 @@ setup_rectangles (GooCanvasItemModel *root)
 static void
 setup_ellipses (GooCanvasItemModel *root)
 {
-  GooCanvasItemModel *ellipse1, *ellipse3;
+  GooCanvasItemModel *ellipse1 G_GNUC_UNUSED, *ellipse3 G_GNUC_UNUSED;
   cairo_pattern_t *pattern;
   static guchar stipple_data[16] = {
     0, 0, 0, 255,   0, 0, 0, 0,
@@ -866,7 +866,7 @@ make_hilbert (GooCanvasItemModel *root)
   char hilbert[] = "urdrrulurulldluuruluurdrurddldrrruluurdrurddldrddlulldrdldrrurd";
   char *c;
   double *pp, *p;
-  GooCanvasItemModel *item;
+  GooCanvasItemModel *item G_GNUC_UNUSED;
   GooCanvasPoints *points;
   cairo_pattern_t *pattern;
   static guchar stipple_data[16] = {
@@ -917,7 +917,7 @@ make_hilbert (GooCanvasItemModel *root)
 static void
 setup_lines (GooCanvasItemModel *root)
 {
-  GooCanvasItemModel *polyline1, *polyline2, *polyline3, *polyline4, *polyline5;
+  GooCanvasItemModel *polyline1 G_GNUC_UNUSED, *polyline2 G_GNUC_UNUSED, *polyline3 G_GNUC_UNUSED, *polyline4 G_GNUC_UNUSED, *polyline5 G_GNUC_UNUSED;
 
   polish_diamond (root);
   make_hilbert (root);
@@ -978,7 +978,7 @@ setup_lines (GooCanvasItemModel *root)
 static void
 setup_polygons (GooCanvasItemModel *root)
 {
-  GooCanvasItemModel *polyline1, *polyline2;
+  GooCanvasItemModel *polyline1 G_GNUC_UNUSED, *polyline2 G_GNUC_UNUSED;
   GooCanvasPoints *points;
   cairo_pattern_t *pattern;
   static guchar stipple_data[16] = {
@@ -1044,7 +1044,7 @@ setup_polygons (GooCanvasItemModel *root)
 static GooCanvasItemModel *
 make_anchor (GooCanvasItemModel *root, double x, double y)
 {
-  GooCanvasItemModel *group, *item;
+  GooCanvasItemModel *group, *item G_GNUC_UNUSED;
   cairo_matrix_t transform = { 0.8, 0.2, -0.3, 0.5, x, y };
 
   group = goo_canvas_group_model_new (root, NULL);
@@ -1073,7 +1073,7 @@ setup_texts (GooCanvasItemModel *root)
 #if 1
   pattern = create_stipple ("blue", stipple_data);
   goo_canvas_text_model_new (make_anchor (root, 420, 20),
-			     "Anchor NW", 0, 0, -1, GTK_ANCHOR_NW,
+			     "Anchor NW", 0, 0, -1, GOO_CANVAS_ANCHOR_NW,
 			     "font", "Sans Bold 24",
 			     "fill_pattern", pattern,
 			     NULL);
@@ -1081,7 +1081,7 @@ setup_texts (GooCanvasItemModel *root)
 
   goo_canvas_text_model_new (make_anchor (root, 470, 75),
 			     "Anchor center\nJustify center\nMultiline text\nb8bit text ÅÄÖåäö",
-			     0, 0, -1, GTK_ANCHOR_CENTER,
+			     0, 0, -1, GOO_CANVAS_ANCHOR_CENTER,
 			     "font", "monospace bold 14",
 			     "alignment", PANGO_ALIGN_CENTER,
 			     "fill_color", "firebrick",
@@ -1091,7 +1091,7 @@ setup_texts (GooCanvasItemModel *root)
 #if 0
   goo_canvas_text_model_new (make_anchor (root, 590, 140),
 			     "Clipped text\nClipped text\nClipped text\nClipped text\nClipped text\nClipped text",
-			     0, 0, -1, GTK_ANCHOR_SE,
+			     0, 0, -1, GOO_CANVAS_ANCHOR_SE,
 			     "font", "Sans 12",
 			     /*"clip", TRUE,*/
 			     /*"clip_width", 50.0,*/
@@ -1104,7 +1104,7 @@ setup_texts (GooCanvasItemModel *root)
 #if 1
   textitem = goo_canvas_text_model_new (make_anchor (root, 420, 240),
 					"This is a very long paragraph that will need to be wrapped over several lines so we can see what happens to line-breaking as the view is zoomed in and out.",
-					0, 0, 180, GTK_ANCHOR_W,
+					0, 0, 180, GOO_CANVAS_ANCHOR_W,
 					"font", "Sans 12",
 					"fill_color", "goldenrod",
 					NULL);
@@ -1113,7 +1113,7 @@ setup_texts (GooCanvasItemModel *root)
 #if 1
   textitem = goo_canvas_text_model_new (root,
 					"Ellipsized text.",
-					20, 420, 115, GTK_ANCHOR_W,
+					20, 420, 115, GOO_CANVAS_ANCHOR_W,
 					"font", "Sans 12",
 					"fill_color", "blue",
 					"ellipsize", PANGO_ELLIPSIZE_END,
@@ -1126,7 +1126,7 @@ static void
 setup_invisible_texts (GooCanvasItemModel *root)
 {
   goo_canvas_text_model_new (root, "Visible above 0.8x", 500, 330, -1,
-			     GTK_ANCHOR_CENTER,
+			     GOO_CANVAS_ANCHOR_CENTER,
 			     "visibility", GOO_CANVAS_ITEM_VISIBLE_ABOVE_THRESHOLD,
 			     "visibility-threshold", 0.8,
 			     NULL);
@@ -1137,7 +1137,7 @@ setup_invisible_texts (GooCanvasItemModel *root)
 			     NULL);
 
   goo_canvas_text_model_new (root, "Visible above 1.5x", 500, 350, -1,
-			     GTK_ANCHOR_CENTER,
+			     GOO_CANVAS_ANCHOR_CENTER,
 			     "visibility", GOO_CANVAS_ITEM_VISIBLE_ABOVE_THRESHOLD,
 			     "visibility-threshold", 1.5,
 			     NULL);
@@ -1148,7 +1148,7 @@ setup_invisible_texts (GooCanvasItemModel *root)
 			     NULL);
 
   goo_canvas_text_model_new (root, "Visible above 3.0x", 500, 370, -1,
-			     GTK_ANCHOR_CENTER,
+			     GOO_CANVAS_ANCHOR_CENTER,
 			     "visibility", GOO_CANVAS_ITEM_VISIBLE_ABOVE_THRESHOLD,
 			     "visibility-threshold", 3.0,
 			     NULL);
@@ -1160,7 +1160,7 @@ setup_invisible_texts (GooCanvasItemModel *root)
 
   /* This should never be seen. */
   goo_canvas_text_model_new (root, "Always Invisible", 500, 390, -1,
-			     GTK_ANCHOR_CENTER,
+			     GOO_CANVAS_ANCHOR_CENTER,
 			     "visibility", GOO_CANVAS_ITEM_INVISIBLE,
 			     NULL);
   goo_canvas_rect_model_new (root, 410.5, 350.5, 180, 15,
@@ -1173,12 +1173,12 @@ setup_invisible_texts (GooCanvasItemModel *root)
 static void
 plant_flower (GooCanvasItemModel *root,
 	      double x, double y,
-	      GtkAnchorType anchor,
+	      GooCanvasAnchorType anchor,
 	      double opacity)
 {
   cairo_pattern_t *pattern;
   cairo_surface_t *surface;
-  GooCanvasItemModel *image;
+  GooCanvasItemModel *image G_GNUC_UNUSED;
   double w, h;
 
   surface = cairo_image_surface_create_from_png ("flower.png");
@@ -1202,7 +1202,7 @@ static void
 setup_images (GooCanvasItemModel *root)
 {
   GdkPixbuf *im;
-  GooCanvasItemModel *image;
+  GooCanvasItemModel *image G_GNUC_UNUSED;
 
   im = gdk_pixbuf_new_from_file ("toroid.png", NULL);
 
@@ -1213,24 +1213,24 @@ setup_images (GooCanvasItemModel *root)
       image = goo_canvas_image_model_new (root, im, 100.0 - w / 2, 225.0 - h / 2,
 					  "width", w,
 					  "height", h,
-					  /* "anchor", GTK_ANCHOR_CENTER, */
+					  /* "anchor", GOO_CANVAS_ANCHOR_CENTER, */
 					  NULL);
       g_object_unref(im);
     }
   else
     g_warning ("Could not find the toroid.png sample file");
 
-  plant_flower (root,  20.0, 170.0, GTK_ANCHOR_NW, 0.3);
-  plant_flower (root, 180.0, 170.0, GTK_ANCHOR_NE, 0.5);
-  plant_flower (root,  20.0, 280.0, GTK_ANCHOR_SW, 0.7);
-  plant_flower (root, 180.0, 280.0, GTK_ANCHOR_SE, 1.0);
+  plant_flower (root,  20.0, 170.0, GOO_CANVAS_ANCHOR_NW, 0.3);
+  plant_flower (root, 180.0, 170.0, GOO_CANVAS_ANCHOR_NE, 0.5);
+  plant_flower (root,  20.0, 280.0, GOO_CANVAS_ANCHOR_SW, 0.7);
+  plant_flower (root, 180.0, 280.0, GOO_CANVAS_ANCHOR_SE, 1.0);
 }
 
 
 static GooCanvasItemModel*
 create_static_model ()
 {
-  GooCanvasItemModel *static_root, *group, *item;
+  GooCanvasItemModel *static_root, *group, *item G_GNUC_UNUSED;
 
   static_root = goo_canvas_group_model_new (NULL, NULL);
 
@@ -1254,7 +1254,7 @@ create_static_model ()
 					     "line-width", 3.0,
 					     NULL);
 
-  item = goo_canvas_text_model_new (group, "N", 40, 320, -1, GTK_ANCHOR_S,
+  item = goo_canvas_text_model_new (group, "N", 40, 320, -1, GOO_CANVAS_ANCHOR_S,
 				    "font", "Sans 12",
 				    NULL);
 
@@ -1310,7 +1310,7 @@ test_simple_transforms (GooCanvasItemModel *root)
 static void
 setup_grids (GooCanvasItemModel *root)
 {
-  GooCanvasItemModel *item;
+  GooCanvasItemModel *item G_GNUC_UNUSED;
 
   item = goo_canvas_grid_model_new (root, 80, 310, 90, 90, 10, 10, 5, 5,
 				    "stroke-color", "yellow",
@@ -1447,9 +1447,8 @@ int
 main (int argc, char *argv[])
 {
   GooCanvasItemModel *model, *static_model;
-  GtkWidget *window;
+  GtkWidget *window G_GNUC_UNUSED;
 
-  gtk_set_locale ();
   gtk_init (&argc, &argv);
 
   model = create_model ();
